@@ -1,6 +1,10 @@
 use self::ctx::Ctx;
 use crate::{
-    debug::dump, marks::Marks, mode::Mode, option::CompressOptions, util::ModuleItemExt,
+    debug::{dump, AssertValid},
+    marks::Marks,
+    mode::Mode,
+    option::CompressOptions,
+    util::ModuleItemExt,
     MAX_PAR_DEPTH,
 };
 use rayon::prelude::*;
@@ -219,6 +223,8 @@ where
             e.visit_mut_children_with(&mut *self.with_ctx(ctx));
         }
 
+        self.remove_invalid(e);
+
         match e {
             Expr::Seq(seq) => {
                 if seq.exprs.is_empty() {
@@ -386,6 +392,10 @@ where
         p.visit_mut_children_with(self);
 
         self.optimize_arrow_method_prop(p);
+
+        if cfg!(feature = "debug") && cfg!(debug_assertions) {
+            p.visit_with(&Invalid { span: DUMMY_SP }, &mut AssertValid);
+        }
     }
 
     fn visit_mut_prop_name(&mut self, p: &mut PropName) {
@@ -408,6 +418,16 @@ where
     fn visit_mut_seq_expr(&mut self, e: &mut SeqExpr) {
         e.visit_mut_children_with(self);
 
+        e.exprs.retain(|e| {
+            if e.is_invalid() {
+                self.changed = true;
+                tracing::debug!("Removing invalid expr in seq");
+                return false;
+            }
+
+            true
+        });
+
         if e.exprs.len() == 0 {
             return;
         }
@@ -488,6 +508,10 @@ where
                 tracing::debug!("after: visit_mut_stmt: {}", text);
             }
         }
+
+        if cfg!(feature = "debug") && cfg!(debug_assertions) {
+            s.visit_with(&Invalid { span: DUMMY_SP }, &mut AssertValid);
+        }
     }
 
     fn visit_mut_stmts(&mut self, items: &mut Vec<Stmt>) {
@@ -499,6 +523,10 @@ where
             Stmt::Empty(..) => false,
             _ => true,
         });
+
+        if cfg!(feature = "debug") && cfg!(debug_assertions) {
+            items.visit_with(&Invalid { span: DUMMY_SP }, &mut AssertValid);
+        }
     }
 
     /// We don't optimize [Tpl] contained in [TaggedTpl].
